@@ -1,13 +1,13 @@
 use super::*;
 
-use crate::Error;
+use anyhow::Result;
 use std::net::SocketAddr;
 use std::str::FromStr;
 
 const DEMO_IP: &str = "1.2.3.4";
 
 #[tokio::test]
-async fn test_chunk_queue() -> Result<(), Error> {
+async fn test_chunk_queue() -> Result<()> {
     let c: Box<dyn Chunk> = Box::new(ChunkUdp::new(
         SocketAddr::from_str("192.188.0.2:1234")?,
         SocketAddr::from_str(&(DEMO_IP.to_owned() + ":5678"))?,
